geowatch.tasks.tracking package
===============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   geowatch.tasks.tracking.abstract_classes
   geowatch.tasks.tracking.agg_functions
   geowatch.tasks.tracking.from_heatmap
   geowatch.tasks.tracking.from_polygon
   geowatch.tasks.tracking.normalize
   geowatch.tasks.tracking.old_polygon_extraction
   geowatch.tasks.tracking.phase
   geowatch.tasks.tracking.polygon_extraction
   geowatch.tasks.tracking.utils
   geowatch.tasks.tracking.visualize

Module contents
---------------

.. automodule:: geowatch.tasks.tracking
   :members:
   :undoc-members:
   :show-inheritance:
